@@ -33,7 +33,9 @@
 ##'   cutoff
 ##' @examples
 ##' ##  Selected calculations
-##' library(tidyverse)
+##' ## library(tidyverse) # only purrr used here for crop2 example
+##' library(dplyr)
+##' library(purrr)
 ##' stress_days_over(boonah, enddate = crop$flower_date[4], ndays = 3,
 ##'                  monitor = TRUE)
 ##' stress_days_over(boonah, enddate = crop$harvest_date[4], ndays = 3,
@@ -44,13 +46,13 @@
 ##' ## Add selected stress days at 'boonah' to 'crop' tibble
 ##' ## using 'map2_dbl' from the 'purrr' package
 ##' ## Note: using equivalent 'furrr' functions can speed up calculations 
-##' crop2 <- crop %>%
+##' crop2 <- crop |>
 ##'   mutate(stressdays25_post_sow_7d =
-##'           map_dbl(sowing_date, function(x)
+##'           purrr::map_dbl(sowing_date, function(x)
 ##'             stress_days_over(boonah, startdate = x, ndays = 7,
 ##'                              stress_temp = 25)),
 ##'           stressdays_flower_harvest =
-##'             map2_dbl(flower_date, harvest_date, function(x, y)
+##'             purrr::map2_dbl(flower_date, harvest_date, function(x, y)
 ##'               stress_days_over(boonah, startdate = x, enddate = y)))
 ##' crop2
 ##' 
@@ -91,13 +93,13 @@ stress_days_over <- function(data, var = NULL, datevar = NULL, ndays = 5,
 
   if (is.null(datevar))
   {
-  tmp_data <- data %>%
+  tmp_data <- data |>
     weather_extract(var = all_of(var_n), datevar = NULL, ndays = ndays,
                     enddate = enddate, startdate = startdate,
                     return.dates = FALSE, monitor = monitor,
                     warn.consecutive = warn.consecutive)
   } else {
-  tmp_data <- data %>%
+  tmp_data <- data |>
     weather_extract(var = all_of(var_n), datevar = {{datevar}}, ndays = ndays,
                     enddate = enddate, startdate = startdate,
                     return.dates = FALSE, monitor = monitor,
